codecs library
Classes
- ActionItem
- ActionsCodec
- Actions codec — coinbase.com/actions (JSON wire format)
- ActionsContent
- Decoded Actions data — a menu of interactive buttons from a bot.
- AttachmentCodec
- Attachment codec implementation
- AttachmentContent
- Data class for attachment content
- ContentType
- Content type information for messages
- ContentTypeId
- ContentTypeId is used to identify the type of content stored in a Message.
- DeleteMessage
- DeleteMessageCodec
- Delete message codec — wraps the protobuf-generated DeleteMessage
- EncodedContent
- EncodedContent bundles the content with metadata identifying its type and parameters required for correct decoding and presentation of the content.
- EncryptedEncodedContent
- GroupUpdated
- A summary of the changes in a commit. Includes added/removed inboxes and changes to metadata
- GroupUpdated_Inbox
- An inbox that was added or removed in this commit
- GroupUpdated_MetadataFieldChange
- A summary of a change to the mutable metadata
- GroupUpdatedCodec
- Group updated codec implementation Uses protobuf-generated GroupUpdated class from transcript_messages.pb.dart
- IntentCodec
- Intent codec — coinbase.com/intent (JSON wire format)
- IntentContent
- Decoded Intent data — the user's selected action in response to a bot menu.
- LeaveRequest
- LeaveRequestCodec
- Leave request codec — wraps the protobuf-generated LeaveRequest
- MultiRemoteAttachment
- MultiRemoteAttachmentCodec
- Multi remote attachment codec — wraps the protobuf-generated MultiRemoteAttachment
- Reaction
- Reaction content data class
- ReactionV2Codec
- Reaction codec v2 implementation
- ReadReceipt
- Read receipt marker - empty payload, timestamp comes from message.sent
- ReadReceiptCodec
- Read receipt codec implementation Content type: xmtp.org/readReceipt v1.0
- RemoteAttachmentCodec
- RemoteAttachmentContent
- RemoteAttachmentInfo
- Reply
- Reply content data class
- ReplyCodec
- Reply codec implementation
- TextCodec
- Text codec implementation for encoding and decoding text messages
- TransactionMetadata
- Optional metadata for a transaction reference.
- TransactionReference
- A reference to an on-chain transaction (a receipt).
- TransactionReferenceCodec
- Transaction reference codec — JSON wire format (XIP-21).
- WalletCall
- A single call within a wallet send calls request (EIP-5792 shape).
- WalletCallMetadata
- Per-call metadata for a wallet send calls request.
- WalletSendCalls
- A wallet send calls request (an invoice / transaction request).
- WalletSendCallsCodec
- Wallet send calls codec — JSON wire format (XIP-59 / EIP-5792).
- XMTPCodec
- Base abstract class for custom codecs
- XMTPCodecRegistry
- Codec registry to manage custom codecs
Enums
- ReactionAction
- Reaction action enum