ActionsContent class

Decoded Actions data — a menu of interactive buttons from a bot.

Constructors

ActionsContent({required String id, required String description, required List<ActionItem> actions})
const
ActionsContent.fromJson(Map<String, dynamic> json)
factory

Properties

actions List<ActionItem>
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited