AttachmentContent class

Data class for attachment content

Constructors

AttachmentContent({required Uint8List data, required String mimeType, required String filename, String? description})
AttachmentContent.fromJson(Map<String, dynamic> json)
factory

Properties

data Uint8List
final
description String?
final
filename String
final
hashCode int
The hash code for this object.
no setterinherited
mimeType String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited