ContentType class

Content type information for messages

Constructors

ContentType({required String authorityId, required String typeId, required int versionMajor})
ContentType.fromMap(Map map)
factory

Properties

authorityId String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
typeId String
final
versionMajor int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited