DeleteMessageCodec class

Delete message codec — wraps the protobuf-generated DeleteMessage

Inheritance

Constructors

DeleteMessageCodec()

Properties

authorityId String
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
typeId String
no setteroverride
versionMajor int
no setteroverride
versionMinor int
no setteroverride

Methods

decode(EncodedContent encodedContent) Future<DeleteMessage>
override
encode(dynamic content) Future<Map<String, dynamic>>
override
getFallback(dynamic content) String?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldPush(dynamic content) bool
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited