IntentContent class

Decoded Intent data — the user's selected action in response to a bot menu.

Constructors

IntentContent({required String id, required String actionId, Map<String, dynamic>? metadata})
const
IntentContent.fromJson(Map<String, dynamic> json)
factory

Properties

actionId String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
metadata Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited