Reaction class

Reaction content data class

Constructors

Reaction({required String reference, required String content, required ReactionAction action, String schema = 'unicode'})
Reaction.fromJson(Map<String, dynamic> json)
factory

Properties

action ReactionAction
final
content String
final
hashCode int
The hash code for this object.
no setterinherited
reference String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schema String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited