RemoteAttachmentCodec class

Inheritance

Constructors

RemoteAttachmentCodec()

Properties

authorityId String
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
typeId String
no setteroverride
versionMajor int
no setteroverride
versionMinor int
no setteroverride

Methods

decode(EncodedContent encodedContent) Future<RemoteAttachmentContent>
override
encode(dynamic content) Future<Map<String, dynamic>>
override
getFallback(dynamic content) String?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldPush(dynamic content) bool
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

encodeEncrypted<T>(T content, XMTPCodec codec, {String? filename}) Future<EncryptedEncodedContent>
Spec-compliant counterpart to load / _fetchDecryptAndParse.
load(RemoteAttachmentContent content) Future<AttachmentContent>
Loads a remote attachment by fetching, decrypting, and parsing it