RemoteAttachmentContent class

Constructors

RemoteAttachmentContent({required String url, required String contentDigest, required Uint8List secret, required Uint8List salt, required Uint8List nonce, required String scheme, required int contentLength, required String filename, String? description})
RemoteAttachmentContent.create({required String url, required String contentDigest, required Uint8List secret, required Uint8List salt, required Uint8List nonce, required int contentLength, required String filename, String? description})
Factory constructor with validation to ensure XMTP spec compliance
factory
RemoteAttachmentContent.fromJson(Map<String, dynamic> json)
factory

Properties

contentDigest String
final
contentLength int
final
description String?
final
filename String
final
hashCode int
The hash code for this object.
no setterinherited
nonce Uint8List
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
salt Uint8List
final
scheme String
final
secret Uint8List
final
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited