Reply class
Reply content data class
Constructors
- Reply({required String reference, required dynamic content, required ContentType contentType})
-
Reply.fromJson(Map<
String, dynamic> json) -
factory
Properties
- content → dynamic
-
final
- contentType → ContentType
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- reference → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited