TransactionReference class

A reference to an on-chain transaction (a receipt).

Constructors

TransactionReference({String? namespace, required String networkId, required String reference, TransactionMetadata? metadata})
TransactionReference.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
metadata TransactionMetadata?
final
namespace String?
final
networkId String
Chain id, normalized to a string (the wire allows string or number).
final
reference String
The on-chain transaction hash.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited