WalletSendCalls class

A wallet send calls request (an invoice / transaction request).

Constructors

WalletSendCalls({required String version, required String chainId, required String from, required List<WalletCall> calls, Map<String, dynamic>? capabilities})
WalletSendCalls.fromJson(Map<String, dynamic> json)
factory

Properties

calls List<WalletCall>
final
capabilities Map<String, dynamic>?
final
chainId String
Chain id in hex (e.g. "0x2105" for Base).
final
from String
The address expected to send the calls (hex).
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited