XMTPCodec class abstract
Base abstract class for custom codecs
Constructors
Properties
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- typeId → String
-
no setter
- versionMajor → int
-
no setter
- versionMinor → int
-
no setter
Methods
-
decode(
EncodedContent encodedContent) → Future -
encode(
dynamic content) → Future< Map< String, dynamic> > -
getFallback(
dynamic content) → String? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldPush(
dynamic content) → bool -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited