XMTPCodecRegistry class

Codec registry to manage custom codecs

Constructors

XMTPCodecRegistry()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCodec(String authorityId, String typeId) XMTPCodec?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerCodec(XMTPCodec codec) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited