generated/content.pb library
Classes
- Compression
- Recognized compression algorithms protolint:disable ENUM_FIELD_NAMES_ZERO_VALUE_END_WITH
- ContentTypeId
- ContentTypeId is used to identify the type of content stored in a Message.
- EncodedContent
- EncodedContent bundles the content with metadata identifying its type and parameters required for correct decoding and presentation of the content.
Extensions
- GeneratedMessageGenericExtensions on T
-
Extensions on
GeneratedMessages.