fallback property

  1. @TagNumber.new(3)
String get fallback

optional fallback description of the content that can be used in case the client cannot decode or render the content

Implementation

@$pb.TagNumber(3)
$core.String get fallback => $_getSZ(2);
  1. @TagNumber.new(3)
set fallback (String value)

Implementation

@$pb.TagNumber(3)
set fallback($core.String value) => $_setString(2, value);