leftInboxes property
/ The inboxes that were removed from the group in response to pending-remove/self-remove requests
Implementation
@$pb.TagNumber(5)
$pb.PbList<GroupUpdated_Inbox> get leftInboxes => $_getList(4);
/ The inboxes that were removed from the group in response to pending-remove/self-remove requests
@$pb.TagNumber(5)
$pb.PbList<GroupUpdated_Inbox> get leftInboxes => $_getList(4);