TransactionMetadata class
Optional metadata for a transaction reference.
Canonical libxmtp lists all six fields, but we keep them optional on decode
for non-conformant senders. extra preserves any keys outside the canonical
schema so they can still be displayed.
Constructors
Properties
- amount → double?
-
final
- currency → String?
-
final
- decimals → int?
-
final
-
extra
→ Map<
String, dynamic> -
final
- fromAddress → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toAddress → String?
-
final
- transactionType → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited