TransactionMetadata class
Optional metadata for a transaction reference
Constructors
- TransactionMetadata({required String transactionType, required String currency, required double amount, required int decimals, required String fromAddress, required String toAddress})
-
TransactionMetadata.fromJson(Map<
String, dynamic> json) -
factory
Properties
- amount → double
-
final
- currency → String
-
final
- decimals → int
-
final
- fromAddress → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toAddress → String
-
final
- transactionType → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited