WalletCall class
A single call within a wallet send calls request (EIP-5792 shape).
Constructors
- WalletCall({String? to, String? data, String? value, String? gas, WalletCallMetadata? metadata})
-
WalletCall.fromJson(Map<
String, dynamic> json) -
factory
Properties
- data → String?
-
Calldata (hex).
final
- gas → String?
-
Gas limit (hex).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- metadata → WalletCallMetadata?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- to → String?
-
Target address (hex).
final
- value → String?
-
Value in wei (hex).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited