WalletCallMetadata class
Per-call metadata for a wallet send calls request.
Constructors
-
WalletCallMetadata({String? description, String? transactionType, Map<
String, dynamic> extra = const {}}) -
WalletCallMetadata.fromJson(Map<
String, dynamic> json) -
factory
Properties
- description → String?
-
final
-
extra
→ Map<
String, dynamic> -
Extra keys flattened alongside description/transactionType on the wire.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transactionType → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited