fallback property
optional fallback description of the content that can be used in case the client cannot decode or render the content
Implementation
@$pb.TagNumber(3)
$core.String get fallback => $_getSZ(2);
Implementation
@$pb.TagNumber(3)
set fallback($core.String value) => $_setString(2, value);